@@ -13,7 +13,7 @@ pub(crate) mod constraints;
 #[derive(Debug, Clone)]
 pub(crate) struct ResolvedSetType {
     pub(crate) setref: String,
-    pub(crate) types: BTreeMap<String, (String, Asn1ResolvedType)>,
+    pub(crate) types: BTreeMap<(String, String), (String, Asn1ResolvedType)>,
 }
 
 #[derive(Debug, Clone)]
